--::::::::::
--room.ads
--::::::::::
with Claw.Basic_Window,
     Claw.Canvas;
with Chop;
with Phil;
with Society;
package Room is

  -- Modified 12/6/98 by tmoran@bix.com to use CLAW instead of ANSY.SYS

  -- Dining Philosophers - Ada 95 edition

  -- Room.Maitre_D is responsible for assigning seats at the
  --   table, "left" and "right" chopsticks, and for reporting
  --   interesting events to the outside world.

  -- Michael B. Feldman, The George Washington University,
  -- July, 1995.

  Table_Size : constant := 5;
  subtype Table_Type is Positive range 1 .. Table_Size;

  Sticks : array (1 .. Table_Size) of Chop.Stick;

  type Status_Report_Type is private;

  task Maitre_D is
    entry Start_Serving;
    entry Report_State (Which_Phil : in Society.Unique_DNA_Codes;
                        State      : in Phil.States;
                        How_Long   : in Natural := 0;
                        Which_Meal : in Natural := 0);
    entry Status_Request(Snapshot : out Status_Report_Type);
  end Maitre_D;

private

  type Chair_Type is record
    Seated   : Boolean := False;
    Activity : Phil.States;
  end record;

  type Status_Report_Type is array(Table_Type) of Chair_Type;

  type Displays is new Claw.Basic_Window.Basic_Window_Type with null record;

  procedure When_Draw(Window  : in out Displays;
                      Easel   : in out Claw.Canvas.Basic_Canvas_Type'Class;
                      Erase_Background: in Boolean;
                      Area    : in     Claw.Rectangle_Type);

end Room;
